==> wordpress-1.5.1-da_DK.tar.gz: wordpress/wp-content/themes/default/sidebar.php <==
﻿	<div id="sidebar">
		<ul>
			
			<li>
				<?php include (TEMPLATEPATH . '/searchform.php'); ?>
			</li>

			<!-- Forfatterinformation er sl&aring;et fra som udgangspunkt. Kommenter v&aelig;k og udfyld dine detaljer hvis du vil bruge det.
			<li><h2>Forfatter</h2>
			<p>Lidt om dig, forfatteren. Ikke noget langt, bare et kort overblik.</p>
			</li>
			-->

			<li>
			<?php /* Hvis dette er en side 404 */ if (is_404()) { ?>
			<?php /* Hvis dette er et kategoriarkiv */ } elseif (is_category()) { ?>
			<p>Du kigger i &oslash;jeblikket i weblog-arkiverne for indl&aelig;g i kategorien <?php single_cat_title(''); ?>.</p>
			
			<?php /* Hvis dette er et dagligt arkiv */ } elseif (is_day()) { ?>
			<p>Du kigger i &oslash;jeblikket i weblog-arkiverne hos <a href="<?php echo get_settings('siteurl'); ?>"><?php echo bloginfo('name'); ?></a>
			fra <?php the_time('l, j. F Y'); ?>.</p>
			
			<?php /* Hvis dette er et m&aring;nedligt arkiv */ } elseif (is_month()) { ?>
			<p>Du kigger i &oslash;jeblikket i weblog-arkiverne hos <a href="<?php echo get_settings('siteurl'); ?>"><?php echo bloginfo('name'); ?></a>
			fra m&aring;neden <?php the_time('F Y'); ?>.</p>

			<?php /* Hvis dette er et &aring;rligt arkiv */ } elseif (is_year()) { ?>
			<p>Du kigger i &oslash;jeblikket i weblog-arkiverne hos <a href="<?php echo get_settings('siteurl'); ?>"><?php echo bloginfo('name'); ?></a>
			fra &aring;ret <?php the_time('Y'); ?>.</p>
			
			<?php /* Hvis dette er et m&aring;nedligt arkiv */ } elseif (is_search()) { ?>
			<p>Du har s&oslash;gt i weblog-arkiverne hos <a href="<?php echo get_settings('siteurl'); ?>"><?php echo bloginfo('name'); ?></a>
			efter <strong>'<?php echo wp_specialchars($s); ?>'</strong>. Hvis du ikke har held med at finde noget, kan du pr&oslash;ve et af disse links.</p>

			<?php /* Hvis dette er et m&aring;nedligt arkiv */ } elseif (isset($_GET['paged']) && !empty($_GET['paged'])) { ?>
			<p>Du kigger i &oslash;jeblikket i weblog-arkiverne hos <a href="<?php echo get_settings('siteurl'); ?>"><?php echo bloginfo('name'); ?></a>.</p>

			<?php } ?>
			</li>

			<?php wp_list_pages('title_li=<h2>Sider</h2>' ); ?>

			<li><h2>Arkiver</h2>
				<ul>
				<?php wp_get_archives('type=monthly'); ?>
				</ul>
			</li>

			<li><h2>Kategorier</h2>
				<ul>
				<?php wp_list_cats('sort_column=name&optioncount=1&hierarchical=0'); ?>
				</ul>
			</li>

			<?php /* Hvis dette er forsiden */ if ( is_home() || is_page() ) { ?>				
				<?php get_links_list(); ?>
				
				<li><h2>Meta</h2>
				<ul>
					<?php wp_register(); ?>
					<li><?php wp_loginout(); ?></li>
					<li><a href="http://validator.w3.org/check/referer" title="Den side er gyldig XHTML 1.0 Transitional">Gyldig <abbr title="eXtensible HyperText Markup Language">XHTML</abbr></a></li>
					<li><a href="http://gmpg.org/xfn/"><abbr title="XHTML Friends Network">XFN</abbr></a></li>
					<li><a href="http://wordpress.org/" title="Denne webside k&oslash;rer WordPress; et moderne, semantisk publiceringsplatform.">WordPress</a></li>
					<?php wp_meta(); ?>
				</ul>
				</li>
			<?php } ?>
			
		</ul>
	</div>

==> wordpress-1.5.1.2-da_DK.tar.gz: wordpress/wp-content/themes/default/sidebar.php <==
	<div id="sidebar">
		<ul>
			
			<li>
				<?php include (TEMPLATEPATH . '/searchform.php'); ?>
			</li>

			<!-- Forfatterinformation er slet fra som udgangspunkt. Udkommenter og udfyld dine detaljer hvis du vil bruge det.
			<li><h2>Forfatter</h2>
			<p>Lidt om dig, forfatteren. Ikke noget langt, bare et kort overblik.</p>
			</li>
			-->

			<li>
			<?php /* Hvis dette er en side 404 */ if (is_404()) { ?>
			<?php /* Hvis dette er et kategoriarkiv */ } elseif (is_category()) { ?>
			<p>Du kigger i &oslash;jeblikket i weblog-arkiverne for indl&aelig;g i kategorien <?php single_cat_title(''); ?>.</p>
			
			<?php /* Hvis dette er et dagligt arkiv */ } elseif (is_day()) { ?>
			<p>Du kigger i &oslash;jeblikket i weblog-arkiverne hos <a href="<?php echo get_settings('siteurl'); ?>"><?php echo bloginfo('name'); ?></a>
			fra <?php the_time('l, j. F Y'); ?>.</p>
			
			<?php /* Hvis dette er et mnedligt arkiv */ } elseif (is_month()) { ?>
			<p>Du kigger i &oslash;jeblikket i weblog-arkiverne hos <a href="<?php echo get_settings('siteurl'); ?>"><?php echo bloginfo('name'); ?></a>
			fra m&aring;neden <?php the_time('F Y'); ?>.</p>

			<?php /* Hvis dette er et rligt arkiv */ } elseif (is_year()) { ?>
			<p>Du kigger i &oslash;jeblikket i weblog-arkiverne hos <a href="<?php echo get_settings('siteurl'); ?>"><?php echo bloginfo('name'); ?></a>
			fra &aring;ret <?php the_time('Y'); ?>.</p>
			
			<?php /* Hvis dette er et mnedligt arkiv */ } elseif (is_search()) { ?>
			<p>Du har s&oslash;gt i weblog-arkiverne hos <a href="<?php echo get_settings('siteurl'); ?>"><?php echo bloginfo('name'); ?></a>
			efter <strong>'<?php echo wp_specialchars($s); ?>'</strong>. Hvis du ikke har held med at finde noget, kan du pr&oslash;ve et af disse links.</p>

			<?php /* Hvis dette er et mnedligt arkiv */ } elseif (isset($_GET['paged']) && !empty($_GET['paged'])) { ?>
			<p>Du kigger i &oslash;jeblikket i weblog-arkiverne hos <a href="<?php echo get_settings('siteurl'); ?>"><?php echo bloginfo('name'); ?></a>.</p>

			<?php } ?>
			</li>

			<?php wp_list_pages('title_li=<h2>Sider</h2>' ); ?>

			<li><h2>Arkiver</h2>
				<ul>
				<?php wp_get_archives('type=monthly'); ?>
				</ul>
			</li>

			<li><h2>Kategorier</h2>
				<ul>
				<?php wp_list_cats('sort_column=name&optioncount=1&hierarchical=0'); ?>
				</ul>
			</li>

			<?php /* Hvis dette er forsiden */ if ( is_home() || is_page() ) { ?>				
				<?php get_links_list(); ?>
				
				<li><h2>Meta</h2>
				<ul>
					<?php wp_register(); ?>
					<li><?php wp_loginout(); ?></li>
					<li><a href="http://validator.w3.org/check/referer" title="Den side er gyldig XHTML 1.0 Transitional">Gyldig <abbr title="eXtensible HyperText Markup Language">XHTML</abbr></a></li>
					<li><a href="http://gmpg.org/xfn/"><abbr title="XHTML Friends Network">XFN</abbr></a></li>
					<li><a href="http://wordpress.org/" title="Denne webside k&oslash;rer WordPress; et moderne, semantisk publiceringsplatform.">WordPress</a></li>
					<?php wp_meta(); ?>
				</ul>
				</li>
			<?php } ?>
			
		</ul>
	</div>
